{% extends 'layout.html' %}

{% block content %}
<article class="article">
    <h2 class="center title">Books</h2>
    <aside>
        <time class="center">Read More and More</time>
    </aside>
    <article class="content">
        <p>I'm Reading:</p>
        <script type="text/javascript" src="http://www.douban.com/service/badge/{{ douban_name }}/?show=dolist&amp;n=10&amp;columns=5&amp;picsize=medium&amp;hidelogo=yes&amp;hideself=yes&amp;cat=book" ></script>
        <p>Have Read:</p>
        <script type="text/javascript" src="http://www.douban.com/service/badge/{{ douban_name }}/?show=collection&amp;n=10&amp;columns=5&amp;picsize=medium&amp;hidelogo=yes&amp;hideself=yes&amp;cat=book" class="center"></script>
    </article>
</article>
{% endblock %}