{% extends 'layout.html' %}

{% block content %}
<article class="article">
    <h2 class="center title">{{ home.title }}</h2>
    <article class="content">
    {{ home.content }}
    </article>
</article>
{% endblock %}

{% block linker %}
{% if repo_switch or book_switch %}
<div class="link center">
    {% if repo_switch %}
    <a href="/github_repo.html">My Github Repo</a>
    {% endif %}
    {% if book_switch %}
    <a href="/douban_book.html">Books</a>
    {% endif %}
</div>
{% endif %}
{% endblock %}