<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{{ title }}</title>
    <link rel="stylesheet" href="static/yue.css" type="text/css">
    <link rel="stylesheet" href="static/style.css" type="text/css">
</head>

<body>
<div class="wrapper yue">
    <header>
        <h1 class="name center"><a href="{{ site_url }}">{{ site_name }}</a></h1>
        <nav class="center nav">
             {% for page in pages if page.type == "page" %}
             <a href="/{{ page.link }}">{{ page.title }}</a>
             {% endfor %}
        </nav>
    </header>
    <div class="container" ng-view>
        {% block content %}
        {% endblock %}
    </div>
        {% block linker %}
        {% endblock %}
    <footer class="center">
        Powered by <a href="https://github.com/JmPotato/Aam">Aam</a> &
        Theme <a href="https://github.com/whtsky/catsup-theme-clean">Clean</a> by
        <a href="http://whouz.com">whtsky</a> and modified by
        <a href="http://ricter.me">Ricter</a> and <a href="http://ipotato.me">JmPotato</a>
    </footer>
</div>
</body>
</html>